:py:mod:`holisticai.explainability.metrics`
===========================================

.. automodule:: holisticai.explainability.metrics
    :no-members:
    :no-inherited-members:

**Global Feature Importance**

.. autosummary::
    :nosignatures:
    :template: function.rst
    :toctree: .generated/

    alpha_score
    xai_ease_score
    position_parity
    rank_alignment
    spread_ratio
    spread_divergence

**Local Feature Importance**

.. autosummary::
    :nosignatures:
    :template: function.rst
    :toctree: .generated/

    data_stability
    feature_stability